<?php

namespace Terrostar\ProductsModule;

use Illuminate\Routing\Router;
use Terrostar\ProductsModule\Rate\RateModel;
use Terrostar\ProductsModule\Rate\RateRepository;
use Terrostar\ProductsModule\Product\ProductModel;
use Terrostar\ProductsModule\Category\CategoryModel;
use Terrostar\ProductsModule\Product\ProductRepository;
use Anomaly\Streams\Platform\Addon\AddonServiceProvider;
use Terrostar\ProductsModule\Category\CategoryRepository;
use Terrostar\ProductsModule\Rate\Contract\RateRepositoryInterface;
use Anomaly\Streams\Platform\Model\Products\ProductsRatesEntryModel;
use Anomaly\Streams\Platform\Model\Products\ProductsProductsEntryModel;
use Anomaly\Streams\Platform\Model\Products\ProductsCategoriesEntryModel;
use Terrostar\ProductsModule\Product\Contract\ProductRepositoryInterface;
use Terrostar\ProductsModule\Category\Contract\CategoryRepositoryInterface;

class ProductsModuleServiceProvider extends AddonServiceProvider
{

    /**
     * Additional addon plugins.
     *
     * @type array|null
     */
    protected $plugins = [];

    /**
     * The addon Artisan commands.
     *
     * @type array|null
     */
    protected $commands = [];

    /**
     * The addon's scheduled commands.
     *
     * @type array|null
     */
    protected $schedules = [];

    /**
     * The addon API routes.
     *
     * @type array|null
     */
    protected $api = [];

    /**
     * The addon routes.
     *
     * @type array|null
     */
    protected $routes = [
        'admin/products'           => 'Terrostar\ProductsModule\Http\Controller\Admin\ProductsController@index',
        'admin/products/create'    => 'Terrostar\ProductsModule\Http\Controller\Admin\ProductsController@create',
        'admin/products/edit/{id}' => 'Terrostar\ProductsModule\Http\Controller\Admin\ProductsController@edit',

        'admin/products/rates'           => 'Terrostar\ProductsModule\Http\Controller\Admin\RatesController@index',
        'admin/products/rates/create'    => 'Terrostar\ProductsModule\Http\Controller\Admin\RatesController@create',
        'admin/products/rates/edit/{id}' => 'Terrostar\ProductsModule\Http\Controller\Admin\RatesController@edit',
        'admin/products/rates/update' => 'Terrostar\ProductsModule\Http\Controller\Admin\RatesController@update',

        'admin/products/categories'           => 'Terrostar\ProductsModule\Http\Controller\Admin\CategoriesController@index',
        'admin/products/categories/create'    => 'Terrostar\ProductsModule\Http\Controller\Admin\CategoriesController@create',
        'admin/products/categories/edit/{id}' => 'Terrostar\ProductsModule\Http\Controller\Admin\CategoriesController@edit',
    ];

    /**
     * The addon middleware.
     *
     * @type array|null
     */
    protected $middleware = [
        //Terrostar\ProductsModule\Http\Middleware\ExampleMiddleware::class
    ];

    /**
     * Addon group middleware.
     *
     * @var array
     */
    protected $groupMiddleware = [
        //'web' => [
        //    Terrostar\ProductsModule\Http\Middleware\ExampleMiddleware::class,
        //],
    ];

    /**
     * Addon route middleware.
     *
     * @type array|null
     */
    protected $routeMiddleware = [];

    /**
     * The addon event listeners.
     *
     * @type array|null
     */
    protected $listeners = [
        //Terrostar\ProductsModule\Event\ExampleEvent::class => [
        //    Terrostar\ProductsModule\Listener\ExampleListener::class,
        //],
    ];

    /**
     * The addon alias bindings.
     *
     * @type array|null
     */
    protected $aliases = [
        //'Example' => Terrostar\ProductsModule\Example::class
    ];

    /**
     * The addon class bindings.
     *
     * @type array|null
     */
    protected $bindings = [
        ProductsRatesEntryModel::class => RateModel::class,
        ProductsProductsEntryModel::class => ProductModel::class,
        ProductsCategoriesEntryModel::class => CategoryModel::class,
    ];

    /**
     * The addon singleton bindings.
     *
     * @type array|null
     */
    protected $singletons = [
        RateRepositoryInterface::class => RateRepository::class,
        ProductRepositoryInterface::class => ProductRepository::class,
        CategoryRepositoryInterface::class => CategoryRepository::class,
    ];

    /**
     * Additional service providers.
     *
     * @type array|null
     */
    protected $providers = [
        //\ExamplePackage\Provider\ExampleProvider::class
    ];

    /**
     * The addon view overrides.
     *
     * @type array|null
     */
    protected $overrides = [
        //'streams::errors/404' => 'module::errors/404',
        //'streams::errors/500' => 'module::errors/500',
    ];

    /**
     * The addon mobile-only view overrides.
     *
     * @type array|null
     */
    protected $mobile = [
        //'streams::errors/404' => 'module::mobile/errors/404',
        //'streams::errors/500' => 'module::mobile/errors/500',
    ];

    /**
     * Register the addon.
     */
    public function register()
    {
        // Run extra pre-boot registration logic here.
        // Use method injection or commands to bring in services.
    }

    /**
     * Boot the addon.
     */
    public function boot()
    {
        // Run extra post-boot registration logic here.
        // Use method injection or commands to bring in services.
    }

    /**
     * Map additional addon routes.
     *
     * @param Router $router
     */
    public function map(Router $router)
    {
        // Register dynamic routes here for example.
        // Use method injection or commands to bring in services.
    }
}
